<p align="center">
  <a href="https://www.classiq.io"><img src="https://uploads-ssl.webflow.com/60000db7a5f449af5e4590ac/6122b22eea7a9583a5c0d560_classiq_RGB_Green_with_margin.png
" alt="Classiq"></a>
</p>
<p align="center">
    <em>The Classiq Quantum Algorithm Design platform helps teams build sophisticated quantum circuits that could not be designed otherwise</em>
</p>

We do this by synthesizing high-level functional models into optimized quantum
circuits, taking into account the constraints that are important to the designer.
Furthermore, we are able to generate circuits for practically any universal gate-based
quantum computer and are compatible with most quantum cloud providers.

See the
[documentation](https://classiquantum.com/reference/getting-started/python-sdk.html)
for information about this extension.

## License

See [license](https://classiq.io/license).
